//  Date
//  E:\Appl\Alaska\Ace10\
//  Anand K Gupta  Mon, 25 Jan 2016

#include "Common.ch"

/***
*
*  Date.prg
*
*  Sample user-defined functions for manipulating dates
*
*/


//------ all funcs in omega manual, donot change to translate directive


/***
*
*  Mdy( <dDate> ) --> cDate
*
*  Convert a date to a string in the format "month dd, yyyy".
*
*  Parameter:
*	  dDate - Date value to convert to a string
*
*  Returns: The date value in "long," string form
*
*/
FUNCTION Mdy( dDate )

   LOCAL cYear

   cYear := STR( YEAR( dDate ))

   RETURN ( CMONTH( dDate ) + " " + LTRIM( STR( DAY( dDate ))) + "," + cYear )



/***
*
*  SMdy( <dDate> ) --> cDate
*
*  Convert a date to a string in the format "mmm dd, yyyy".
*
*  Parameter:
*	  dDate - Date value to convert to a string
*
*  Returns: The date value in "short" string form
*
*/
FUNCTION SMdy( dDate )          // mmm dd, yyyy

   LOCAL cYear

   cYear := STR( YEAR( dDate ))

   RETURN ( left(CMONTH( dDate ),3) + " " + LTRIM( STR( DAY( dDate ))) ;
                                            + "," + cYear )



/***
*
*  SWDmy( <dDate> ) --> short cDate
*
*  Convert a date to string formatted as "www dd mmm yyyy".
*
*  Parameter:
*	  dDate - Date value to convert
*
*  Returns: The date value with week day prefixed
*
*/
FUNCTION SWDmy( dDate )
   LOCAL cYear,cDate

	if empty(dDate)
		cDate := ''
	else
		cYear := STR( YEAR( dDate ))
		cDate := left(CDOW( dDate ), 3) + " " + LTRIM( STR( DAY( dDate ))) + ;
				 " " + left(CMONTH( dDate ), 3) + cYear
	endif
RETURN cDate




/***
*
*  WDmy( <dDate> ) --> cDate
*
*  Convert a date to string formatted as "week dd month yyyy".
*
*  Parameter:
*	  dDate - Date value to convert
*
*  Returns: The date value with week day prefixed
*
*/
FUNCTION WDmy( dDate )
   LOCAL cYear,cDate

	if empty(dDate)
		cDate := ''
	else
		cYear := STR( YEAR( dDate ))
		cDate := CDOW( dDate ) + " " + LTRIM( STR( DAY( dDate ))) + " " + ;
				 CMONTH( dDate ) + cYear
	endif
RETURN cDate




/***
*
*  Dmy( <dDate> ) --> cDate
*
*  Convert a date to string formatted as "dd month yyyy".
*
*  Parameter:
*	  dDate - Date value to convert
*
*  Returns: The date value in european date format
*
*/
FUNCTION Dmy( dDate )
   LOCAL cYear,cDate

	if empty(dDate)
		cDate := ''
	else
		cYear := STR( YEAR( dDate ))
		cDate := LTRIM( STR( DAY( dDate ))) + " " + CMONTH( dDate ) + cYear
	endif
RETURN cDate

/***
*
*  SDmy( <dDate> ) --> cDate
*
*  Convert a date to string formatted as "dd mmm yyyy".
*
*  Parameter:
*	  dDate - Date value to convert
*
*  Returns: The date value in european date format
*
*/
FUNCTION SDmy( dDate )
   LOCAL cYear,cDate

	if empty(dDate)
		cDate := ''
	else
		cYear := STR( YEAR( dDate ))
		cDate := LTRIM( STR( DAY( dDate ))) + " " + left( CMONTH( dDate ) ,3) + cYear
	endif
RETURN cDate



/***
*
*  DateAsAge( <dDate>, <currentDate> ) --> nAge
*
*  Convert a date of birth to an age in years.
*
*  Parameter:
*	  dDate - Birthdate for which to calculate the age
*
*  Returns: The number of years elapsed since <dDate>
*
*/
FUNCTION DateAsAge( dDate, currentDate )

   LOCAL nAge := 0

   default currentDate to date()

   IF YEAR( currentDate ) > YEAR( dDate )

	  nAge := YEAR( DATE() ) - YEAR( dDate )

	  // Decrease the age by one if the date (month/day) has not yet
	  // occurred this year
	  IF ( MONTH( currentDate ) < MONTH( dDate )  .OR.	;
		 ( MONTH( currentDate ) == MONTH( dDate ) .AND. ;
		   DAY( currentDate ) < DAY( dDate )			;
		 ))

		 --nAge

	  ENDIF
   ENDIF

   RETURN nAge

/***
*
*  DateIsLeap( <dDate> ) --> lLeap
*
*  Determine if the year of a supplied date is a leap year
*
*/
FUNCTION DateIsleap( dDate )

   LOCAL nYear := YEAR( dDate )

*	 RETURN (( nYear % 4 ) == 0 )	 .AND. ;
*			((( nYear % 100 ) != 0 ) .OR.  ;
*			(( nYear % 400 ) == 0)	 )

retu ! empty(ctod("29/02/"+str(nYear)))     // thanks PC Mag Fri 22-11-96

*	DLastDt() .........  returns the last date of the month of given date
*	dateIn ............  given date (current date)
*	Returns ...........  last date
*	e.g. ..............  dLDT := DLastDt(CTOD('26/12/94'))
*						 dLcurrDT := DLastDt()
*						
*
func DLastDt( dateIn )
local cSavDateFormat := set( _SET_DATEFORMAT, "DD/MM/YYYY" )
local dLast_Date

default dateIn to date()

// The last day of the month is the day before the first of the next month
if month(dateIn) == 12
    *---------- special case for december
    dLast_Date := ctod( "31/12/" + transform( year(dateIn), "9999" ) )
else
    dLast_Date := ctod( transform( 01,              "99/"  ) + ;
                        transform( month(dateIn)+1, "99/"  ) + ;
                        transform( year(dateIn),    "9999" ) ) - 1
endif

set( _SET_DATEFORMAT, cSavDateFormat )
return ( dLast_Date )


*	DFirstDt() ........  returns the first date of the month of given date
*	dateIn ............  given date (current date)
*	Returns ...........  first date
*	e.g. ..............  dFDT := DFirstDt(date())
*						
*
func DFirstDt( dateIn )
local cSavDateFormat := set( _SET_DATEFORMAT, "DD/MM/YYYY" )
local dFirst_Date, adate

default dateIn to date()

dFirst_Date := ctod( transform( 01,             "99/"  ) + ;
                     transform( month(dateIn),  "99/"  ) + ;
                     transform( year(dateIn),   "9999" ) )

set( _SET_DATEFORMAT, cSavDateFormat )
return ( dFirst_Date )

